OCIS Document Index

# OSCN navigation

| Index of Available Documents |

Up One Level | Show Levels |

# Oklahoma Attorney General's Opinions
(STOKAG)
1977 to Present
Search

Decisions published in 2014

2014 OK AG 1, 01/13/2014, Question Submitted by: The Honorable Scott C. Martin, State Representative, District 46

2014 OK AG 2, 02/06/2014, Question Submitted by: The Honorable Leslie Osborn, State Representative, District 47

2014 OK AG 3, 02/19/2014, Question Submitted by: The Honorable Marty Quinn, State Representative, District 9

2014 OK AG 4, 03/10/2014, Question Submitted by: The Honorable Mike Shelton, State Representative, District 97

2014 OK AG 5, 04/11/2014, Question Submitted by: The Honorable Wade Roussellot, State Representative, District 12

2014 OK AG 6, 04/22/2014, Question Submitted by: Ms. Deby Snodgrass, Executive Director, Oklahoma Tourism and Recreation Department

2014 OK AG 7, 06/18/2014, Question Submitted by: The Honorable Scott M. Inman, State Representative, District 94

2014 OK AG 7, 06/18/2014, Question Submitted by: The Honorable Scott M. Inman, State Representative, District 94